==> portal-transparencia-1.124.2.zip: BOOT-INF/classes/db/sql/contab/programatica-desdobramento.sql <==
SELECT DISTINCT(E.DESDOBRADESP) AS CODIGO,     
(SELECT DISTINCT(DESD.DESCRICAO) FROM DESDOBRADESP DESD
  WHERE DESD.ENTIDADE = DESP.ENTIDADE
    AND DESD.EXERCICIO = DESP.EXERCICIO
    AND DESD.DESPESA = SUBSTR(DESP.PROGRAMATICA,ELEM.POSICAO,6)
    AND DESD.DESDOBRAMENTO = E.DESDOBRADESP
    AND DESD.SUBDESDOBRAMENTO = '00') AS DESCRICAO
  FROM EMPENHO E
  LEFT OUTER JOIN FORNECEDOR F
    ON E.FORNECEDOR = F.FORNECEDOR
  LEFT OUTER JOIN DESPESA DESP
    ON E.ENTIDADE = DESP.ENTIDADE
   AND E.EXERCICIO = DESP.EXERCICIO
   AND E.PROGRAMATICA = DESP.PROGRAMATICA
   AND E.FONTERECURSO = DESP.FONTERECURSO
  LEFT OUTER JOIN NIVEISMODELODESPESA ORG
    ON DESP.MODELODESPESA = ORG.MODELODESPESA
   AND ORG.TIPO = 'P'
   AND ORG.ORDEM = 1
  LEFT OUTER JOIN NIVEISMODELODESPESA UNID
    ON DESP.MODELODESPESA = UNID.MODELODESPESA
   AND UNID.TIPO = 'C'
   AND UNID.ORDEM = 2
  LEFT OUTER JOIN NIVEISMODELODESPESA FUNCAO
    ON DESP.MODELODESPESA = FUNCAO.MODELODESPESA
   AND FUNCAO.TIPO = 'P'
   AND FUNCAO.ORDEM = 3
  LEFT OUTER JOIN NIVEISMODELODESPESA SUBFUNCAO
    ON DESP.MODELODESPESA = SUBFUNCAO.MODELODESPESA
   AND SUBFUNCAO.TIPO = 'P'
   AND SUBFUNCAO.ORDEM = 4
  LEFT OUTER JOIN NIVEISMODELODESPESA PROG
    ON DESP.MODELODESPESA = PROG.MODELODESPESA
   AND PROG.TIPO = 'P'
   AND PROG.ORDEM = 5
LEFT OUTER JOIN NIVEISMODELODESPESA PROJ
  ON DESP.MODELODESPESA = PROJ.MODELODESPESA
 AND PROJ.TIPO = 'P'
 AND PROJ.ORDEM = 6
  LEFT OUTER JOIN NIVEISMODELODESPESA ELEM
    ON DESP.MODELODESPESA = ELEM.MODELODESPESA
   AND ELEM.TIPO = 'C'
   AND ELEM.ORDEM = 7
 WHERE E.ENTIDADE = :entidade
   AND E.EXERCICIO = :exercicio
   AND DESP.PROGRAMATICA IS NOT NULL

==> portal-transparencia-2.029.0.zip: BOOT-INF/classes/db/sql/contab/programatica-desdobramento.sql <==
SELECT DISTINCT(E.DESDOBRADESP) AS CODIGO,     
(SELECT DISTINCT(DESD.DESCRICAO) FROM ${db.contabilidade.schema}.DESDOBRADESP DESD
  WHERE DESD.ENTIDADE = DESP.ENTIDADE
    AND DESD.EXERCICIO = DESP.EXERCICIO
    AND DESD.DESPESA = SUBSTR(DESP.PROGRAMATICA,ELEM.POSICAO,6)
    AND DESD.DESDOBRAMENTO = E.DESDOBRADESP
    AND DESD.SUBDESDOBRAMENTO = '00') AS DESCRICAO
  FROM ${db.contabilidade.schema}.EMPENHO E
  LEFT OUTER JOIN ${db.contabilidade.schema}.FORNECEDOR F
    ON E.FORNECEDOR = F.FORNECEDOR
  LEFT OUTER JOIN ${db.contabilidade.schema}.DESPESA DESP
    ON E.ENTIDADE = DESP.ENTIDADE
   AND E.EXERCICIO = DESP.EXERCICIO
   AND E.PROGRAMATICA = DESP.PROGRAMATICA
   AND E.FONTERECURSO = DESP.FONTERECURSO
  LEFT OUTER JOIN ${db.contabilidade.schema}.NIVEISMODELODESPESA ORG
    ON DESP.MODELODESPESA = ORG.MODELODESPESA
   AND ORG.TIPO = 'P'
   AND ORG.ORDEM = 1
  LEFT OUTER JOIN ${db.contabilidade.schema}.NIVEISMODELODESPESA UNID
    ON DESP.MODELODESPESA = UNID.MODELODESPESA
   AND UNID.TIPO = 'C'
   AND UNID.ORDEM = 2
  LEFT OUTER JOIN ${db.contabilidade.schema}.NIVEISMODELODESPESA FUNCAO
    ON DESP.MODELODESPESA = FUNCAO.MODELODESPESA
   AND FUNCAO.TIPO = 'P'
   AND FUNCAO.ORDEM = 3
  LEFT OUTER JOIN ${db.contabilidade.schema}.NIVEISMODELODESPESA SUBFUNCAO
    ON DESP.MODELODESPESA = SUBFUNCAO.MODELODESPESA
   AND SUBFUNCAO.TIPO = 'P'
   AND SUBFUNCAO.ORDEM = 4
  LEFT OUTER JOIN ${db.contabilidade.schema}.NIVEISMODELODESPESA PROG
    ON DESP.MODELODESPESA = PROG.MODELODESPESA
   AND PROG.TIPO = 'P'
   AND PROG.ORDEM = 5
LEFT OUTER JOIN ${db.contabilidade.schema}.NIVEISMODELODESPESA PROJ
  ON DESP.MODELODESPESA = PROJ.MODELODESPESA
 AND PROJ.TIPO = 'P'
 AND PROJ.ORDEM = 6
  LEFT OUTER JOIN ${db.contabilidade.schema}.NIVEISMODELODESPESA ELEM
    ON DESP.MODELODESPESA = ELEM.MODELODESPESA
   AND ELEM.TIPO = 'C'
   AND ELEM.ORDEM = 7
 WHERE E.ENTIDADE = :entidade
   AND E.EXERCICIO = :exercicio
   AND DESP.PROGRAMATICA IS NOT NULL
